==> x7-repository-2.0.8.RELEASE-sources.jar: x7/repository/dao/DataSourceUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package x7.repository.dao;

import org.springframework.jdbc.datasource.DataSourceUtils;

import javax.sql.DataSource;
import java.sql.Connection;
import java.sql.SQLException;


public class DataSourceUtil {


    public static Connection getConnection() throws SQLException {

        String key = DataSourceHolder.WRITEABLE_DEFAULT;
        DataSource ds = DataSourceHolder.getDataSource();

        Connection conn = DataSourceUtils.getConnection(ds);

        return conn;
    }

    public static void releaseConnection(Connection conn){

        String key = DataSourceHolder.WRITEABLE_DEFAULT;
        DataSource ds = DataSourceHolder.getDataSource();

        DataSourceUtils.releaseConnection(conn,ds);
    }


}

==> x7-repository-2.1.0.RELEASE-sources.jar: x7/repository/dao/DataSourceUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package x7.repository.dao;

import org.springframework.jdbc.datasource.DataSourceUtils;

import javax.sql.DataSource;
import java.sql.Connection;
import java.sql.SQLException;


public class DataSourceUtil {


    public static Connection getConnection() {

//        String key = DataSourceHolder.WRITEABLE_DEFAULT;
        DataSource ds = DataSourceHolder.getDataSource();

        Connection conn = DataSourceUtils.getConnection(ds);

        return conn;
    }

    public static void releaseConnection(Connection conn){

//        String key = DataSourceHolder.WRITEABLE_DEFAULT;
        DataSource ds = DataSourceHolder.getDataSource();

        DataSourceUtils.releaseConnection(conn,ds);
    }


}
